@@ -8,10 +8,11 @@ use Carp qw/croak/;
 use Const::Fast;
 use Scalar::Util qw/blessed/;
 use IPC::Signal qw/sig_num/;
+use Linux::FD ();
 
 use parent 'IO::Handle';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 const my $fail_fd => -1;
 
@@ -32,11 +33,11 @@ __END__
 
 =head1 NAME
 
-Linux::FD::Signal - Signal filehandles
+Linux::FD::Signal - Signal filehandles for Linux
 
 =head1 VERSION
 
-Version 0.002
+Version 0.004
 
 =head1 SYNOPSIS
 
@@ -48,7 +49,7 @@ Version 0.002
 
 =head2 new($sigmask)
 
-This creates a signalfd file descriptor that can be used to accept signals targeted at the caller. This provides an alternative to the use of a signal handler or sigwaitinfo, and has the advantage that the file descriptor may be monitored by select, poll, and epoll. The handle will be non-blocking by default.
+This creates a signalfd file descriptor that can be used to accept signals targeted at the caller. This provides an alternative to the use of a signal handler or sigwaitinfo, and has the advantage that the file descriptor may be monitored by select, poll, and epoll.
 
 The $sigmask argument specifies the set of signals that the caller wishes to accept via the file descriptor. This should either be a signal name(without the C<SIG> prefix) or a L<POSIX::SigSet|POSIX> object. Normally, the set of signals to be received via the file descriptor should be blocked to prevent the signals being handled according to their default dispositions. It is not possible to receive SIGKILL or SIGSTOP signals via a signalfd file descriptor; these signals are silently ignored if specified in $sigmask.
 
